/////////////// INTERVAL ARITHMETIC
//--------------------------------------------------------
function z=i_empty()         // Generates the empty interval 
	z=[%nan,%nan]    // %nan means not a number
endfunction
//--------------------------------------------------------
function b=i_isempty(x)    // Check if the interval z is empty
	b=(isnan(x(1))|isnan(x(2)))
endfunction
//--------------------------------------------------------
function b=i_in(a,x)      //Check if the real a is inside the interval x
	b=(a>=x(1))&(a<=x(2))
        if i_isempty(x) then b=%F
        end
endfunction
//--------------------------------------------------------
function b=i_subset(x,y)  //Check if the interval x is included in y
	if i_isempty(x) then b=%T          // %T means True
	elseif i_isempty(y) then b=%F   // %F means False
        else b=(x(1)>=y(1))&(x(2)<=y(2))
        end
endfunction
//--------------------------------------------------------
function z=i_inter(x,y)   //Intersection between intervals x and y
	z=[max(x(1),y(1)),min(x(2),y(2))];
         if i_isempty(x)|i_isempty(y)|(z(1)>z(2)) then z=i_empty()
	 end;
endfunction
//--------------------------------------------------------
function z=i_union(x,y)   // Returns the smallest interval which contains the union of x and y
	 z=[min(x(1),y(1)),max(x(2),y(2))];
         if i_isempty(x) then z=y
         end;
         if i_isempty(y) then z=x
         end;
endfunction
//-----------------------------------------
function z=i_plus(x,y); 	
	 z=x+y; 
endfunction
//-----------------------------------------
function z=i_minus(x,y)
	 z=[x(1)-y(2),x(2)-y(1)];
endfunction
//-----------------------------------------
function z=i_mult(x,y)
	 v=[x(1)*y(1),x(1)*y(2),x(2)*y(1),x(2)*y(2)];
	 z=[min(v),max(v)];
endfunction
//-----------------------------------------
function y=i_inv(x)
        if  i_isempty(x) 	then y=i_empty()
	elseif  i_in(0,x) 	then y=[-%inf,%inf]
        else y=[1/x(2),1/x(1)];
  	end
endfunction
//-----------------------------------------
function z=i_div(x,y)
	 a=i_inv(y); 
	 z=i_mult(x,a);
endfunction
//-----------------------------------------------------------------------
function z=i_exp(x)
         if (i_isempty(x)) then z=i_empty();
                        else z=[exp(x(1)),exp(x(2))];
        end; 
endfunction
//-----------------------------------------------------------------------
function z=i_log(x)
       if (i_isempty(x))|(x(2)<=0) then z=i_empty();
       elseif i_in(0,x) then z=[-%inf,log(x(2))];
       elseif (x(1)>0) then z=[log(x(1)),log(x(2))];
       end;
endfunction
//-----------------------------------------------------------------------
function z=i_sqr(x)
        if 	i_isempty(x) then	z=i_empty();
        elseif 	x(2)<=0  	then z=[(x(2))^2,(x(1))^2];
        elseif 	x(1)>=0 	then z=[(x(1))^2,(x(2))^2];
        elseif       i_in(0,x) 	then z=[0,max(x(1),x(2))^2];
        end;
endfunction
